%macro sia_link_node_fltr_wt_calc(sia_project_pk=,sia_wrkflw_step_id=);

	%let sia_proc_starttime = %sysfunc(datetime());
	ods listing close;

	*** Input parameters **************************;
	%let sia_project_pk 	 = &sia_project_pk.;
	%let sia_wrkflw_step_id  = &sia_wrkflw_step_id.;

	*** Global parameters defined & declared in other macros *****;
	%let sia_apdm_lib 	 = &sia_apdm_lib.;
	%let sia_bisdata_lib = &sia_bisdata_lib.;
	%let sia_imdata_lib  = &sia_imdata_lib.;
	%let sia_bisdata_type= &sia_bisdata_type.;
	%let sia_execution_mode= &sia_execution_mode.;
	%let sia_prm_val_xctn_md_dstrbtd = &sia_prm_val_xctn_md_dstrbtd.;
	%let sia_prm_val_xctn_md_nndstrbtd = &sia_prm_val_xctn_md_nndstrbtd.;
	%let sia_sas_lib 	 = &sia_sas_lib.;
	%let sia_text_separator = &sia_text_separator. ;
	%let sia_wrkflw_status_inprgs = &sia_wrkflw_status_inprgs.;
	%let sia_wrkflw_status_exectd = &sia_wrkflw_status_exectd.;
	%let sia_wrkflw_status_error  = &sia_wrkflw_status_error.;
	%let sia_wrkflw_status_enable = &sia_wrkflw_status_enable.;
	%let sia_wrkflw_status_disable = &sia_wrkflw_status_disable.;
	%let tbl_type_cd_trn 		= &tbl_type_cd_trn.;
	%let tbl_clmn_type_cd_msr 	= &tbl_clmn_type_cd_msr.;
	%let sia_smd_error_tbl 		= &sia_smd_error_tbl.;
	%let sia_smd_err_key 		=;
	%let sia_wrkflw_step_id_lnkndpr = &sia_wrkflw_step_id_lnkndpr.;
	%let sia_wrkflw_step_id_cmbld 	= &sia_wrkflw_step_id_cmbld.;
	%let sia_wrkflw_step_id_cntrmsr = &sia_wrkflw_step_id_cntrmsr.;
	%let sia_wrkflw_step_id_rlass  	= &sia_wrkflw_step_id_rlass.;
	%let sia_lnk_wt_exp_param_id    = &sia_lnk_wt_exp_param_id.;
	%let sia_rptvar_id_nodermvd = &sia_rptvar_id_nodermvd.;
	%let sia_rptvar_id_linkrmvd = &sia_rptvar_id_linkrmvd.;
	%let sia_comm_size_param_id = &sia_comm_size_param_id.;
	%let sia_wrkflw_step_id_dxtr = &sia_wrkflw_step_id_dxtr.;
	%let sia_sql_ip_trace_flg = &sia_sql_ip_trace_flg.;
	%let sia_mtdt_fldr_path_prj = &sia_mtdt_fldr_path_prj.;
	%let sia_mtdt_fldr_prjdata  = &sia_mtdt_fldr_prjdata.;
	%let hadoop_connect_string = &hadoop_connect_string.;
	%let hadoop_disconnect_string = &hadoop_disconnect_string.;
	%let hadoop_pass_through_start = &hadoop_pass_through_start.;
	%let hadoop_pass_through_end = &hadoop_pass_through_end.;
	
	/* Turning option sql_ip_trace on */
	%if %kupcase("&sia_sql_ip_trace_flg.") eq "Y" %then %do;	/* i18nOK:Line */
		options SQL_IP_TRACE = ALL;
	%end;

	*** Global Variable for Degree Variable Column_pk & Column_nm ***;
	%let sia_in_degree_clmn_pk 	= &sia_in_degree_clmn_pk.;
	%let sia_out_degree_clmn_pk = &sia_out_degree_clmn_pk.;
	%let sia_in_degree_clmn_nm  = &sia_in_degree_clmn_nm.;
	%let sia_out_degree_clmn_nm = &sia_out_degree_clmn_nm.;

	*** Reporting Variable ID ***;
	%let sia_rptvar_id_numnode = &sia_rptvar_id_numnode.;
	%let sia_rptvar_id_numlink = &sia_rptvar_id_numlink.;

	*** Maximum and Minimum Possible values for Upper and Lower limits of Link-Node Measures ***;
	%let sia_lnknde_msr_max_up_lmt  = &sia_lnknde_msr_max_up_lmt.;
	%let sia_lnknde_msr_min_low_lmt = &sia_lnknde_msr_min_low_lmt.;

	*** Error Handling if Work Flow Step ID is Null ***;
	%if &sia_wrkflw_step_id. eq  %then %do;
		%let sia_smd_err_key = E_00013; *** Work Flow Step ID is Null ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	*** Updating Work Flow Status for Link and Node Processing Step (IN PROGRESS) ***;
	proc sql noprint;
			update &sia_apdm_lib..project_wrkflw_step
			set WRKFLW_STEP_STATUS_CD = kupcase("&sia_wrkflw_status_inprgs.")
			where kupcase(WRKFLW_STEP_ID) = kupcase("&sia_wrkflw_step_id_lnkndpr.") and
				  project_pk = &sia_project_pk.;
	quit;

	*** Error Handling if table updation failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00007; *** Table Updation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	*** 1. Getting Information (TABLE_PK) of Source XDR table and project current run number ***;
	%let sia_prjct_curr_run_num =.;
	%let sia_xdr_tbl_pk 	   =.;

	proc sql noprint;
		select 	project_curr_run_num into :sia_prjct_curr_run_num
		from	&sia_apdm_lib..project
		where 	project_pk = &sia_project_pk.;

		select 	a.table_pk into :sia_xdr_tbl_pk
		from	&sia_apdm_lib..table_mstr a,
			 	&sia_apdm_lib..project b,
			 	&sia_apdm_lib..source_profile_x_table c
		where 	b.project_pk = &sia_project_pk. and
				b.source_profile_pk = c.source_profile_pk and
				c.table_pk = a.table_pk and
				kupcase(a.table_type_cd) = kupcase("&tbl_type_cd_trn.");
	quit;

	*** Error Handling if Data Selection from Table Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00015; *** Data Selection from Table Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	%let sia_prjct_curr_run_num = &sia_prjct_curr_run_num.;
	%let sia_xdr_tbl_pk 	   	= &sia_xdr_tbl_pk.;

	***	2. Getting the list of columns (of type: MEASURES) of the XDR table **;
	%let sia_xdr_measures_cnt =.;
	%let sia_xdr_measures     =.;
	%let sia_xdr_measures_pk  =.;
	/* i18NOK:Begin */ 
		*** Count() function here can not be internationalized. ***;
	proc sql noprint;
		select 	count(a.table_column_nm), a.table_column_nm, a.table_column_pk 
				into :sia_xdr_measures_cnt, :sia_xdr_measures separated by "&sia_text_separator.", :sia_xdr_measures_pk separated by "&sia_text_separator."
		from	&sia_apdm_lib..table_column_mstr a
		where 	a.table_pk = &sia_xdr_tbl_pk. and
				kupcase(a.table_column_type_cd) = kupcase("&tbl_clmn_type_cd_msr.");
	quit;
	/* i18NOK:End */

	*** Error Handling if Data Selection from Table Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00015; *** Data Selection from Table Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	%let sia_xdr_measures_cnt = &sia_xdr_measures_cnt.;
	%let sia_xdr_measures     = &sia_xdr_measures.;
	%let sia_xdr_measures_pk  = &sia_xdr_measures_pk.;

	/************************************************************************************************************
	*							WHERE CLAUSE & FILTERED NODE TABLE CREATION										*
	*																											*
	*	1.	Getting Lower & Upper limit values for all Link Measures and										*
	*		Creating macro variable (sia_lnk_msr_fltr_where_exp) which store the where expression for 			*
	*		these limits on link measures.																		*
	*	2.	Getting Lower & Upper limit values for all Node Degree Measures (Degree in/out).					*
	*	3. 	Creating temporary table which contains filtered nodes as per the in/out degree lower/upper limit	*
	************************************************************************************************************/

	*** 1. Getting Lower & Upper limit values for all Link Measures ***;
	%let sia_lnk_msr_fltr_where_exp =;
    %let check_sum=0;
	%do sia_i=1 %to &sia_xdr_measures_cnt.;
		%let sia_link_msr&sia_i. 	= %sysfunc(scan(&sia_xdr_measures.,&sia_i.,&sia_text_separator.));	/* i18nOK:Line */
		%let sia_link_msr_pk&sia_i. = %sysfunc(scan(&sia_xdr_measures_pk.,&sia_i.,&sia_text_separator.));	/* i18nOK:Line */
		%let sia_link_msr_low_lmt&sia_i.= .;
		%let sia_link_msr_up_lmt&sia_i.	= .;

		proc sql noprint;
			select 	lower_limit, upper_limit into :sia_link_msr_low_lmt&sia_i., :sia_link_msr_up_lmt&sia_i.
			from 	&sia_apdm_lib..project_before_filter_smmry
			where 	project_pk = &sia_project_pk. and
					project_curr_run_num = &sia_prjct_curr_run_num. and
					table_column_pk = &&sia_link_msr_pk&sia_i..;
		quit;

		*** Error Handling if Data Selection from Table Failed ***;
		%sia_err_chk(type=SQL);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00015; *** Data Selection from Table Failed ***;
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;


    %let check_limit_set&sia_i. = .;
	%if &&sia_link_msr_low_lmt&sia_i.. ne . or &&sia_link_msr_up_lmt&sia_i.. ne .  %then %do;
	       %let check_limit_set&sia_i.=1;
	%end;
	%else %if &&sia_link_msr_low_lmt&sia_i.. eq . and  &&sia_link_msr_up_lmt&sia_i.. eq . %then %do ;
	       %let check_limit_set&sia_i.= 0;
    %end;

    %let check_limit_set&sia_i=&&check_limit_set&sia_i.;
	%put &&check_limit_set&sia_i.;

	%if &&check_limit_set&sia_i..=1 %then %do;

	     %if &&sia_link_msr_low_lmt&sia_i.. eq . %then %do;
			%let sia_link_msr_low_lmt&sia_i.= &sia_lnknde_msr_min_low_lmt.;
		%end;
		%let sia_link_msr_low_lmt&sia_i.= &&sia_link_msr_low_lmt&sia_i..;

		%if &&sia_link_msr_up_lmt&sia_i.. eq . %then %do;
			%let sia_link_msr_up_lmt&sia_i.	= &sia_lnknde_msr_max_up_lmt.;
		%end;
		%let sia_link_msr_up_lmt&sia_i.	= &&sia_link_msr_up_lmt&sia_i..;
        %let sia_lnk_msr_fltr_where_exp = &sia_lnk_msr_fltr_where_exp. &&sia_link_msr&sia_i.. between &&sia_link_msr_low_lmt&sia_i.. and &&sia_link_msr_up_lmt&sia_i.. and;

		%let sia_lnk_msr_fltr_where_exp = &sia_lnk_msr_fltr_where_exp.;
        %put &sia_lnk_msr_fltr_where_exp.;
	%end;

	%let check_sum = %sysevalf(&check_sum. + &&check_limit_set&sia_i.);
	%put &check_sum.;
   %end;
		

	***	Macro variable containing where clause expression for all Link measures ***;
	%let sia_lnk_msr_fltr_where_exp = &sia_lnk_msr_fltr_where_exp.;

	*** 2. Getting Lower & Upper limit values for all Node Degree Measures (Degree in/out). ***;
	%let sia_in_degree_low_lmt 	= .;
	%let sia_in_degree_up_lmt 	= .;
	%let sia_out_degree_low_lmt = .;
	%let sia_out_degree_up_lmt 	= .;

	proc sql noprint;
		select 	lower_limit, upper_limit into :sia_in_degree_low_lmt, :sia_in_degree_up_lmt
		from 	&sia_apdm_lib..project_before_filter_smmry
		where 	project_pk = &sia_project_pk. and
				project_curr_run_num = &sia_prjct_curr_run_num. and
				table_column_pk = &sia_in_degree_clmn_pk.;

		select 	lower_limit, upper_limit into :sia_out_degree_low_lmt, :sia_out_degree_up_lmt
		from 	&sia_apdm_lib..project_before_filter_smmry
		where 	project_pk = &sia_project_pk. and
				project_curr_run_num = &sia_prjct_curr_run_num. and
				table_column_pk = &sia_out_degree_clmn_pk.;
	quit;

	*** Error Handling if Data Selection from Table Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00015; *** Data Selection from Table Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	%let sia_check_in_degree_limit=;
    %let  sia_check_out_degree_limit=;
    %let sia_check_degree_limit =;

	%if &sia_in_degree_low_lmt. ne . or  &sia_in_degree_up_lmt. ne . %then %do;

      %let sia_check_in_degree_limit =yes;
   %end;
   %else %do;
      %let sia_check_in_degree_limit =no;
   %end;
   %let sia_check_in_degree_limit =&sia_check_in_degree_limit.;
      
   %if &sia_out_degree_low_lmt. ne . or &sia_out_degree_up_lmt. ne . %then %do;

      %let  sia_check_out_degree_limit =yes;
   %end;
   %else %do;
      %let  sia_check_out_degree_limit =no;
   %end;
     
   %let sia_check_out_degree_limit =&sia_check_out_degree_limit.;

   %if &sia_in_degree_low_lmt. eq . and  &sia_in_degree_up_lmt. eq . and
          &sia_out_degree_low_lmt. eq . and &sia_out_degree_up_lmt. eq . %then %do;
          %let sia_check_degree_limit =no;
   %end;

   %if &sia_check_in_degree_limit.=yes and &sia_check_out_degree_limit.=yes %then %do;
 
     %if &sia_in_degree_low_lmt. eq . %then %do;
		%let sia_in_degree_low_lmt 	= &sia_lnknde_msr_min_low_lmt.;
	 %end;
	 %let sia_in_degree_low_lmt 	= &sia_in_degree_low_lmt.;

	 %if &sia_in_degree_up_lmt. eq . %then %do;
		%let sia_in_degree_up_lmt 	= &sia_lnknde_msr_max_up_lmt.;
	 %end;
	 %let sia_in_degree_up_lmt 	= &sia_in_degree_up_lmt.;

	 %if &sia_out_degree_low_lmt. eq . %then %do;
		%let sia_out_degree_low_lmt = &sia_lnknde_msr_min_low_lmt.;
	 %end;
	 %let sia_out_degree_low_lmt = &sia_out_degree_low_lmt.;

	 %if &sia_out_degree_up_lmt. eq . %then %do;
		%let sia_out_degree_up_lmt 	= &sia_lnknde_msr_max_up_lmt.;
	 %end;
	 %let sia_out_degree_up_lmt 	= &sia_out_degree_up_lmt.;
  

	%if %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		options dbidirectexec;
	%end;

	proc sql noprint;
		create table &sia_imdata_lib..cla_lnf_i1_&sia_project_pk. as
		select 	entity_id
		from 	&sia_bisdata_lib..cla_de_p2_&sia_project_pk.
		where   &sia_in_degree_clmn_nm. between &sia_in_degree_low_lmt. and &sia_in_degree_up_lmt.
        and       
				&sia_out_degree_clmn_nm. between &sia_out_degree_low_lmt. and &sia_out_degree_up_lmt.;
	quit;

	*** Error Handling if Table Creation Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;
 %end;
 %else  %if &sia_check_in_degree_limit = no and &sia_check_out_degree_limit =yes %then %do;

      %if &sia_out_degree_low_lmt. eq . %then %do;
		%let sia_out_degree_low_lmt = &sia_lnknde_msr_min_low_lmt.;
	  %end;
	  %let sia_out_degree_low_lmt = &sia_out_degree_low_lmt.;

	  %if &sia_out_degree_up_lmt. eq . %then %do;
	 	%let sia_out_degree_up_lmt 	= &sia_lnknde_msr_max_up_lmt.;
	  %end;
	  %let sia_out_degree_up_lmt 	= &sia_out_degree_up_lmt.;

      %if %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		options dbidirectexec;
	  %end;

	  proc sql noprint;
		create table &sia_imdata_lib..cla_lnf_i1_&sia_project_pk. as
		select 	entity_id
		from 	&sia_bisdata_lib..cla_de_p2_&sia_project_pk.
		where  	&sia_out_degree_clmn_nm. between &sia_out_degree_low_lmt. and &sia_out_degree_up_lmt.;
	 quit;

	 *** Error Handling if Table Creation Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;
	
%end;
%else  %if &sia_check_in_degree_limit = yes and &sia_check_out_degree_limit =no %then %do;

      %if &sia_in_degree_low_lmt. eq . %then %do;
		%let sia_in_degree_low_lmt 	= &sia_lnknde_msr_min_low_lmt.;
	  %end;
	  %let sia_in_degree_low_lmt 	= &sia_in_degree_low_lmt.;

	  %if &sia_in_degree_up_lmt. eq . %then %do;
		%let sia_in_degree_up_lmt 	= &sia_lnknde_msr_max_up_lmt.;
	  %end;
	  %let sia_in_degree_up_lmt 	= &sia_in_degree_up_lmt.;

      %if %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		options dbidirectexec;
	  %end;

	  proc sql noprint;
		create table &sia_imdata_lib..cla_lnf_i1_&sia_project_pk. as
		select 	entity_id
		from 	&sia_bisdata_lib..cla_de_p2_&sia_project_pk.
		where  	&sia_in_degree_clmn_nm. between &sia_in_degree_low_lmt. and &sia_in_degree_up_lmt.;
	 quit;

	 *** Error Handling if Table Creation Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;
	
%end;
%else %if &sia_check_degree_limit. = no %then %do;
   %if %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		options dbidirectexec;
	%end;

	proc sql noprint;
		create table &sia_imdata_lib..cla_lnf_i1_&sia_project_pk. as
		select 	entity_id
		from 	&sia_bisdata_lib..cla_de_p2_&sia_project_pk.;
    quit;

	*** Error Handling if Table Creation Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;
	
%end;
   
	
	/************************************************************************************************
	*							FILTERED TRANSACTION TABLE CREATION									*
	*																								*
	*	1. 	Creating temporary table which contains all filtered nodes & Links.								*
	*	2.	Fetching Link Weight Calculation Formula from apdm.project_param table.					*
	*	3.	Computing Link Weight and creating final filter transaction table.						*
	************************************************************************************************/
	
	*** 1. 	Creating Temporary Table which contains all filtered nodes & Links. ***;
	Proc sql noprint;
	%if %sysfunc(exist(&sia_imdata_lib..cla_lnf_i2_&sia_project_pk.)) = 1 %then %do;
			drop table &sia_imdata_lib..cla_lnf_i2_&sia_project_pk.;
		%end;

    %if %sysfunc(exist(&sia_imdata_lib..cla_lnf_i4_&sia_project_pk.)) = 1 %then %do;
			drop table &sia_imdata_lib..cla_lnf_i4_&sia_project_pk.;
		%end;
   quit;

   	*** Error Handling If Table deletion Failed ***;

	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00008; *** Table deletion Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

/***** checking for whether limits have been provided and including filtering for measures***/

    %if %eval(&check_sum. ne 0) %then %do;

	%if %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		options dbidirectexec;
	%end;

	proc sql noprint;
		create table &sia_imdata_lib..cla_lnf_i2_&sia_project_pk. as
			select	a.*
			from 	&sia_bisdata_lib..cla_de_p1_&sia_project_pk. a,
					&sia_imdata_lib..cla_lnf_i1_&sia_project_pk. b
			where 	&sia_lnk_msr_fltr_where_exp. 
					a.from_entity_id = b.entity_id;
					
		create table &sia_imdata_lib..cla_lnf_i4_&sia_project_pk. as
			select	a.*
			from 	&sia_imdata_lib..cla_lnf_i2_&sia_project_pk. a,
					&sia_imdata_lib..cla_lnf_i1_&sia_project_pk. b
			where 	&sia_lnk_msr_fltr_where_exp. 
					a.to_entity_id = b.entity_id;	
	quit;

	*** Error Handling if Table Creation Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;
  %end;
 %else %do;

    %if %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		options dbidirectexec;
	%end;

	proc sql noprint;
		create table &sia_imdata_lib..cla_lnf_i2_&sia_project_pk. as
			select	a.*
			from 	&sia_bisdata_lib..cla_de_p1_&sia_project_pk. a,
					&sia_imdata_lib..cla_lnf_i1_&sia_project_pk. b
			where   a.from_entity_id = b.entity_id;
					
		create table &sia_imdata_lib..cla_lnf_i4_&sia_project_pk. as
			select	a.*
			from 	&sia_imdata_lib..cla_lnf_i2_&sia_project_pk. a,
					&sia_imdata_lib..cla_lnf_i1_&sia_project_pk. b
			where 	a.to_entity_id = b.entity_id;	
	quit;

   *** Error Handling if Table Creation Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;
  %end;  

	*** 2.	Fetching Link Weight Expression from apdm.project_param table. ***;
	%let sia_lnk_wt_exp =.;
	proc sql noprint;
		select 	param_userdefined_value into :sia_lnk_wt_exp
		from	&sia_apdm_lib..project_param
		where	project_pk = &sia_project_pk. and
				kupcase(wrkflw_step_id) = kupcase("&sia_wrkflw_step_id.") and
				kupcase(param_id) = kupcase("&sia_lnk_wt_exp_param_id.");
	quit;
	%let sia_lnk_wt_exp = &sia_lnk_wt_exp.;

	*** Error Handling if Link Weight Expression not available ***;
	%if "&sia_lnk_wt_exp." eq "." %then %do;
		%let sia_smd_err_key = E_00014; *** Link Weight Expression not available ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	*** 3.	Computing Link Weight and creating final filter transaction table. ***;

	*** Drop last to last run data if exists ***;
	%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p1_&sia_project_pk.)) = 1 AND %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p1_&sia_project_pk._l)) = 1 %then %do;
		proc sql noprint;
			drop table &sia_bisdata_lib..cla_lnf_p1_&sia_project_pk._l;
		quit;

		*** Error Handling if table deletion failed ***;
		%sia_err_chk(type=SQL);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00008; *** Table Deletion Failed ***;
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;
	%end;

	*** If Aggreagted Source table of last run exists, it would be renamed to keep last run data ***;
	%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p1_&sia_project_pk.)) %then %do;
		proc datasets library = &sia_bisdata_lib.;
			change cla_lnf_p1_&sia_project_pk. = cla_lnf_p1_&sia_project_pk._l;
		run;
		quit;
		
		*** Error Handling If Renaming Table Failed ***;
		%sia_err_chk(type=DATA);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00043; *** Renaming Table Failed ***;
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;
	%end;

	%if %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		options dbidirectexec;
	%end;

	proc sql noprint;
		create table &sia_bisdata_lib..cla_lnf_p1_&sia_project_pk. as
			select 	from_entity_id, to_entity_id, 
					case when &sia_lnk_wt_exp. <= 0 then 1 else &sia_lnk_wt_exp. end as link_weight_val
			from 	&sia_imdata_lib..cla_lnf_i4_&sia_project_pk.;
	quit;


	*** Error Handling If Table Creation Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	/************************************************************************************************************
	*							UNDIRECTED GRAPH DATA CREATION 													*
	*																											*
	*	1. 	Making Undirected data from Directed data.															*
	*	2. 	Copy Directed and Undirectd data to SAS data Library to be used in Community Detection Algorithm.	*
	************************************************************************************************************/

	*** Deleting temporary table if allready exists ***;
	proc sql noprint;
		%if %sysfunc(exist(&sia_imdata_lib..cla_lnf_i3_&sia_project_pk.)) = 1 %then %do;
			drop table &sia_imdata_lib..cla_lnf_i3_&sia_project_pk.;
		%end;
	quit;

	*** Error Handling If Table deletion Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00008; *** Table deletion Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	*** Drop last to last run data if exists ***;
	%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p2_&sia_project_pk.)) = 1 AND %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p2_&sia_project_pk._l)) = 1 %then %do;
		proc sql noprint;
			drop table &sia_bisdata_lib..cla_lnf_p2_&sia_project_pk._l;
		quit;

		*** Error Handling if table deletion failed ***;
		%sia_err_chk(type=SQL);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00008; *** Table Deletion Failed ***;
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;
	%end;

	*** If filtered undirected table of last run exists, it would be renamed to keep last run data ***;
	%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p2_&sia_project_pk.)) %then %do;
		proc datasets library = &sia_bisdata_lib.;
			change cla_lnf_p2_&sia_project_pk. = cla_lnf_p2_&sia_project_pk._l;
		run;
		quit;
		
		*** Error Handling If Renaming Table Failed ***;
		%sia_err_chk(type=DATA);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00043; *** Renaming Table Failed ***;
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;
	%end;

	*** 1. Making Undirected data from Directed data ***;
	%if %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		options dbidirectexec;
	%end;

	proc sql noprint;
		create table &sia_imdata_lib..cla_lnf_i3_&sia_project_pk. as
			select 
				case when from_entity_id < to_entity_id then from_entity_id else to_entity_id end as from_entity_id,
				case when from_entity_id < to_entity_id then to_entity_id else from_entity_id end as to_entity_id,
				link_weight_val
			from &sia_bisdata_lib..cla_lnf_p1_&sia_project_pk.;

		create table &sia_bisdata_lib..cla_lnf_p2_&sia_project_pk. as
			select 
				from_entity_id,
				to_entity_id,
				sum(link_weight_val) as link_weight_val
			from &sia_imdata_lib..cla_lnf_i3_&sia_project_pk.
			group by from_entity_id, to_entity_id ;
	quit;

	*** Error Handling If Table Creation Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	*** 2. Copy Directed and Undirectd data to SAS data Library if Business Database is NOT in SAS 
		   and execution mode is NONDISTRIBUTED ***;
	%if %kupcase("&sia_execution_mode.") eq %kupcase("&sia_prm_val_xctn_md_nndstrbtd.") AND %kupcase("&sia_bisdata_type.") ne "SAS" %then %do;		/* i18nOK:Line */
		proc copy in = &sia_bisdata_lib. out = &sia_sas_lib.;
			select cla_lnf_p1_&sia_project_pk. cla_lnf_p2_&sia_project_pk.;
		run;

		*** Error Handling If Copying Table Failed ***;
		%sia_err_chk(type=DATA);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00019; *** Copying Table Failed ***;
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;
	%end;
	
	*** When Execution mode is DISTRIBUTED then Undirected Reciprocal Link data would be created and distributed on GRID ***;
	%if %kupcase("&sia_execution_mode.") eq %kupcase("&sia_prm_val_xctn_md_dstrbtd.") %then %do;

		*** Drop last to last run data if exists ***;
		%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p3_&sia_project_pk.)) = 1 AND %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p3_&sia_project_pk._l)) = 1 %then %do;
			proc sql noprint;
				drop table &sia_bisdata_lib..cla_lnf_p3_&sia_project_pk._l;
			quit;

			*** Error Handling if table deletion failed ***;
			%sia_err_chk(type=SQL);
			%if %sysevalf(&sia_err_cd. > 4) %then %do;
				%let sia_smd_err_key = E_00008; *** Table Deletion Failed ***;
				%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
				%goto exit;
			%end;
		%end;

		*** If filtered undirected reciprocal table of last run exists, it would be renamed to keep last run data ***;
		%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p3_&sia_project_pk.)) %then %do;
			proc datasets library = &sia_bisdata_lib.;
				change cla_lnf_p3_&sia_project_pk. = cla_lnf_p3_&sia_project_pk._l;
			run;
			quit;
			
			*** Error Handling If Renaming Table Failed ***;
			%sia_err_chk(type=DATA);
			%if %sysevalf(&sia_err_cd. > 4) %then %do;
				%let sia_smd_err_key = E_00043; *** Renaming Table Failed ***;
				%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
				%goto exit;
			%end;
		%end;

		options dbidirectexec;

		%if %kupcase("&sia_bisdata_type.") eq "HADOOP" %then %do;		/* i18nOK:Line */
			proc sql noprint;
				&hadoop_connect_string.;
				&hadoop_pass_through_start.
						create table cla_lnf_p3_&sia_project_pk. as
			        	select distinct from_entity_id, to_entity_id, link_weight_val
						from (select from_entity_id, to_entity_id, link_weight_val
							  from 	cla_lnf_p2_&sia_project_pk.
							  union all
				        	  select to_entity_id as from_entity_id, from_entity_id as to_entity_id, link_weight_val
							  from 	cla_lnf_p2_&sia_project_pk.) unionResult
						&hadoop_pass_through_end.;
				&hadoop_disconnect_string.;
			quit;
		%end;
		%else %do;
			proc sql noprint;
				create table &sia_bisdata_lib..cla_lnf_p3_&sia_project_pk. as
					select from_entity_id, to_entity_id, link_weight_val
					from &sia_bisdata_lib..cla_lnf_p2_&sia_project_pk.
					union
					select to_entity_id as from_entity_id, from_entity_id as to_entity_id, link_weight_val
					from &sia_bisdata_lib..cla_lnf_p2_&sia_project_pk. ;
			quit;
		%end;
		*** Error Handling If Table Creation Failed ***;
		%sia_err_chk(type=SQL);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00009; *** Table Creation Failed ***;
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;
	%end;

	/****************************************************************************************************
	*		Writing/Updating Output tables' names in APDM												*
	****************************************************************************************************/
	%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p1_&sia_project_pk.)) = 1 %then %do;
		%sia_output_tbl_nm_in_apdm(sia_project_pk=&sia_project_pk.,sia_wrkflw_step_id=&sia_wrkflw_step_id.,sia_output_tbl_nm=cla_lnf_p1,sia_output_tbl_type=coredata);
	%end;
	%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p2_&sia_project_pk.)) = 1 %then %do;
		%sia_output_tbl_nm_in_apdm(sia_project_pk=&sia_project_pk.,sia_wrkflw_step_id=&sia_wrkflw_step_id.,sia_output_tbl_nm=cla_lnf_p2,sia_output_tbl_type=coredata);
	%end;
	%if %sysfunc(exist(&sia_bisdata_lib..cla_lnf_p3_&sia_project_pk.)) = 1 %then %do;
		%sia_output_tbl_nm_in_apdm(sia_project_pk=&sia_project_pk.,sia_wrkflw_step_id=&sia_wrkflw_step_id.,sia_output_tbl_nm=cla_lnf_p3,sia_output_tbl_type=coredata);
	%end;

	/****************************************************************************************************
	*							DATA INSERTION INTO REPORTING TABLE 									*
	*																									*
	*	1. Counting Nodes and Links in Filtered data at Link-Node Processing Step.						*
	*	2. Getting Node and Link count at Data Extraction step (before link-node processing/filtering).	*
	*	3. Inserting calculated link-node processing step Summary data into reporting table in apdm.	*
	****************************************************************************************************/

	*** 1. Counting Nodes and Links in Filtered data at Link-Node Processing Step ***; 
	/* i18NOK:Begin */ 
		*** Count() function here can not be internationalized. ***;
	options dbidirectexec;
	proc sql noprint;
		%if %kupcase("&sia_bisdata_type.") eq "HADOOP" %then %do;
			&hadoop_connect_string.;
			&hadoop_pass_through_start.
					create table cla_lnf_i5_&sia_project_pk. as
		        	select distinct entity_id
					from (select from_entity_id as entity_id 
						  from 	cla_lnf_p1_&sia_project_pk.
						  union all
			        	  select to_entity_id as entity_id
						  from 	cla_lnf_p1_&sia_project_pk.) unionResult
					&hadoop_pass_through_end.;
			&hadoop_disconnect_string.;

			select count(entity_id) into :sia_lnkndpr_nde_cnt
			from &sia_bisdata_lib..cla_lnf_i5_&sia_project_pk.;
		%end;
		%else %do;
			select count(1) into :sia_lnkndpr_nde_cnt
			from (select distinct from_entity_id as entity_id from &sia_bisdata_lib..cla_lnf_p1_&sia_project_pk.
				  union
				  select distinct to_entity_id as entity_id from &sia_bisdata_lib..cla_lnf_p1_&sia_project_pk.);
		%end;
		
		select count(1) into :sia_lnkndpr_lnk_cnt
		from &sia_bisdata_lib..cla_lnf_p1_&sia_project_pk.;
	quit;
	/* i18NOK:End */ 

	*** Error Handling If Data Selection from Table Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00015; *** Data Selection from Table Failed ***; 
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;
	
	%let sia_lnkndpr_nde_cnt = &sia_lnkndpr_nde_cnt.;
	%let sia_lnkndpr_lnk_cnt = &sia_lnkndpr_lnk_cnt.;

	*** Error Handling if No Data available in Filtered Table: cla_lnf_p1 ***;
	%if &sia_lnkndpr_lnk_cnt. < 1 %then %do;
		%let sia_smd_err_key = E_00040; *** No Data available in Filtered Table: cla_lnf_p1 ***;
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	*** 2. Getting Node and Link count at Data Extraction step (before link-node processing/filtering) ***;
	proc sql noprint;
		select report_variable_val into :sia_dxtr_nde_cnt
		from &sia_apdm_lib..project_wrkflw_step_data
		where project_pk = &sia_project_pk. and
			  kupcase(wrkflw_step_id) = kupcase("&sia_wrkflw_step_id_dxtr.") and
			  kupcase(report_variable_id) = kupcase("&sia_rptvar_id_numnode.") and
			  project_curr_run_num = &sia_prjct_curr_run_num.;

		select report_variable_val into :sia_dxtr_lnk_cnt
		from &sia_apdm_lib..project_wrkflw_step_data
		where project_pk = &sia_project_pk. and
			  kupcase(wrkflw_step_id) = kupcase("&sia_wrkflw_step_id_dxtr.") and
			  kupcase(report_variable_id) = kupcase("&sia_rptvar_id_numlink.") and
			  project_curr_run_num = &sia_prjct_curr_run_num.;
	quit;

	*** Error Handling If Data Selection from Table Failed ***;
	%sia_err_chk(type=SQL);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00015; *** Data Selection from Table Failed ***; 
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	%let sia_dxtr_nde_cnt = &sia_dxtr_nde_cnt.;
	%let sia_dxtr_lnk_cnt = &sia_dxtr_lnk_cnt.;

	%let sia_rptvar_val_nodermvd = %sysevalf(((&sia_dxtr_nde_cnt. - &sia_lnkndpr_nde_cnt.)/&sia_dxtr_nde_cnt.)*100);
	%let sia_rptvar_val_linkrmvd = %sysevalf(((&sia_dxtr_lnk_cnt. - &sia_lnkndpr_lnk_cnt.)/&sia_dxtr_lnk_cnt.)*100);

	***  3. Inserting calculated link-node processing step Summary data into reporting table in apdm. ***;
	proc sql noprint;
		*** Deleting records from workflow step table, if any exists for current project pk and current run ***;
		delete from &sia_apdm_lib..project_wrkflw_step_data
		where project_pk = &sia_project_pk. and
			  kupcase(wrkflw_step_id) = kupcase("&sia_wrkflw_step_id.") and
		  	  project_curr_run_num = &sia_prjct_curr_run_num.;

		*** Error Handling If Data Deletion from table failed ***;
		%sia_err_chk(type=SQL);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00018; *** Data Deletion from table failed ***; 
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;

		insert into &sia_apdm_lib..project_wrkflw_step_data (PROJECT_PK, WRKFLW_STEP_ID, PROJECT_CURR_RUN_NUM, REPORT_VARIABLE_ID, REPORT_VARIABLE_VAL)
			values (&sia_project_pk.,"&sia_wrkflw_step_id.",&sia_prjct_curr_run_num.,"&sia_rptvar_id_numnode.",&sia_lnkndpr_nde_cnt.)
			values (&sia_project_pk.,"&sia_wrkflw_step_id.",&sia_prjct_curr_run_num.,"&sia_rptvar_id_numlink.",&sia_lnkndpr_lnk_cnt.)
			values (&sia_project_pk.,"&sia_wrkflw_step_id.",&sia_prjct_curr_run_num.,"&sia_rptvar_id_nodermvd.",&sia_rptvar_val_nodermvd.)
			values (&sia_project_pk.,"&sia_wrkflw_step_id.",&sia_prjct_curr_run_num.,"&sia_rptvar_id_linkrmvd.",&sia_rptvar_val_linkrmvd.);

		*** Error Handling If Data Insertion Into table Failed ***;
		%sia_err_chk(type=SQL);
		%if %sysevalf(&sia_err_cd. > 4) %then %do;
			%let sia_smd_err_key = E_00002; *** Data Insertion Into table Failed ***; 
			%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
			%goto exit;
		%end;

	quit;

	%let sia_mtdt_data_fldr_pth = &sia_mtdt_fldr_path_prj./&sia_project_pk./&sia_mtdt_fldr_prjdata.;
	%let sia_mtdt_tbl_lst = cla_lnf_p1_&sia_project_pk. cla_lnf_p2_&sia_project_pk. cla_lnf_p1_&sia_project_pk._l cla_lnf_p2_&sia_project_pk._l;

	%if %kupcase("&sia_execution_mode.") eq %kupcase("&sia_prm_val_xctn_md_dstrbtd.") %then %do;
		%let sia_mtdt_tbl_lst = &sia_mtdt_tbl_lst. cla_lnf_p3_&sia_project_pk. cla_lnf_p3_&sia_project_pk._l;
	%end;

	proc metalib;
		omr (liburi = "SASLibrary?@libref='&sia_bisdata_lib.'");		/* i18nOK:Line */
		folder = "&sia_mtdt_data_fldr_pth.";
		update_rule=(delete);
		select (&sia_mtdt_tbl_lst.);
	run;

	*** Error Handling If Registering Table into Metadata Failed ***;
	%sia_err_chk(type=DATA);
	%if %sysevalf(&sia_err_cd. > 4) %then %do;
		%let sia_smd_err_key = E_00044; *** Registering Table into Metadata Failed ***; 
		%put %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_err_key., NOQUOTE));
		%goto exit;
	%end;

	%exit:

	
	/************************************************************************************************
	*								DELETING INTERMEDIATE TABLES									*
	************************************************************************************************/

	proc sql noprint;
		%if %sysfunc(exist(&sia_imdata_lib..cla_lnf_i1_&sia_project_pk.)) = 1 %then %do;
			drop table &sia_imdata_lib..cla_lnf_i1_&sia_project_pk.;
		%end;
		%if %sysfunc(exist(&sia_imdata_lib..cla_lnf_i2_&sia_project_pk.)) = 1 %then %do;
			drop table &sia_imdata_lib..cla_lnf_i2_&sia_project_pk.;
		%end;
		%if %sysfunc(exist(&sia_imdata_lib..cla_lnf_i3_&sia_project_pk.)) = 1 %then %do;
			drop table &sia_imdata_lib..cla_lnf_i3_&sia_project_pk.;
		%end;
		%if %sysfunc(exist(&sia_imdata_lib..cla_lnf_i4_&sia_project_pk.)) = 1 %then %do;
			drop table &sia_imdata_lib..cla_lnf_i4_&sia_project_pk.;
		%end;
		%if %sysfunc(exist(&sia_imdata_lib..cla_lnf_i5_&sia_project_pk.)) = 1 %then %do;
			drop table &sia_imdata_lib..cla_lnf_i5_&sia_project_pk.;
		%end;
	quit;


	/************************************************************************************************
	*								UPDATING WORK FLOW STEP STATUS									*
	************************************************************************************************/

	%if &sia_smd_err_key. eq  %then %do;
		%let sia_lnkndpr_step_status = &sia_wrkflw_status_exectd.;
		%let sia_cmbld_step_status	 = &sia_wrkflw_status_enable.;
		%let sia_cntrmsr_step_status = &sia_wrkflw_status_disable.;
		%let sia_rlass_step_status 	 = &sia_wrkflw_status_disable.;
	%end;
	%else %do;
		%let sia_lnkndpr_step_status = &sia_wrkflw_status_error.;
		%let sia_cmbld_step_status 	 = &sia_wrkflw_status_disable.;
		%let sia_cntrmsr_step_status = &sia_wrkflw_status_disable.;
		%let sia_rlass_step_status 	 = &sia_wrkflw_status_disable.;
	%end;

	proc sql noprint;	
		update &sia_apdm_lib..project_wrkflw_step
		set wrkflw_step_status_cd = kupcase("&sia_lnkndpr_step_status.")
		where kupcase(ktrim(kleft(wrkflw_step_id))) = kupcase("&sia_wrkflw_step_id_lnkndpr.") and
			  project_pk = &sia_project_pk.;

		update &sia_apdm_lib..project_wrkflw_step
		set wrkflw_step_status_cd = kupcase("&sia_cmbld_step_status.")
		where kupcase(ktrim(kleft(wrkflw_step_id))) = kupcase("&sia_wrkflw_step_id_cmbld.") and
			  project_pk = &sia_project_pk.;

		update &sia_apdm_lib..project_wrkflw_step
		set wrkflw_step_status_cd = kupcase("&sia_cntrmsr_step_status.")
		where kupcase(ktrim(kleft(wrkflw_step_id))) = kupcase("&sia_wrkflw_step_id_cntrmsr.") and
			  project_pk = &sia_project_pk.;

		update &sia_apdm_lib..project_wrkflw_step
		set wrkflw_step_status_cd = kupcase("&sia_rlass_step_status.")
		where kupcase(ktrim(kleft(wrkflw_step_id))) = kupcase("&sia_wrkflw_step_id_rlass.") and
			  project_pk = &sia_project_pk.;
	quit;

	/************************************************************************************************
	*								COMPUTING PROCESSING TIME 										*
	************************************************************************************************/

	%let sia_smd_msg_key_strt = MSG_00001;
	%let sia_timestamp_msg_strt = %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_msg_key_strt., NOQUOTE));

	%let sia_smd_msg_key_end = MSG_00002;
	%let sia_timestamp_msg_end = %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_msg_key_end., NOQUOTE));

	%let sia_smd_msg_key_tot = MSG_00003;
	%let sia_timestamp_msg_tot = %sysfunc(sasmsg(sashelp.&sia_smd_error_tbl., &sia_smd_msg_key_tot., NOQUOTE));

	%let sia_proc_endtime = %sysfunc(datetime());
	%let sia_proc_exectime = %sysevalf((&sia_proc_endtime.-&sia_proc_starttime.)/60);

	data _null_;
		starttime = put(&sia_proc_starttime.,nldatm.);
		endtime = put(&sia_proc_endtime.,nldatm.);
		put "&sia_timestamp_msg_strt. " starttime "| &sia_timestamp_msg_end. " endtime ;
		put "&sia_timestamp_msg_tot. &sia_proc_exectime.";
	run;

%mend sia_link_node_fltr_wt_calc;
